==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/outputs/DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormat.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property csv The CSV dataset used in the monitoring job. Fields are documented below.
 * @property json The JSON dataset used in the monitoring job. Fields are documented below.
 */
public data class DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormat(
    public val csv: DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsv? =
        null,
    public val json: DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJson? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.sagemaker.outputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormat):
            DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormat =
            DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormat(
                csv = javaType.csv().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.sagemaker.kotlin.outputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsv.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                json = javaType.json().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.sagemaker.kotlin.outputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJson.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/outputs/DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormat.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property csv The CSV dataset used in the monitoring job. Fields are documented below.
 * @property json The JSON dataset used in the monitoring job. Fields are documented below.
 */
public data class DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormat(
    public val csv: DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsv? =
        null,
    public val json: DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJson? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.sagemaker.outputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormat): DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormat =
            DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormat(
                csv = javaType.csv().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.sagemaker.kotlin.outputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatCsv.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                json = javaType.json().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.sagemaker.kotlin.outputs.DataQualityJobDefinitionDataQualityJobInputBatchTransformInputDatasetFormatJson.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
